api.currentuser.v1.test_helpers.user package — Argus-Toolbelt 1.0 documentation

# api.currentuser.v1.test_helpers.user package

## Submodules

## api.currentuser.v1.test_helpers.user.get_current_user module

`api.currentuser.v1.test_helpers.user.get_current_user.` `forbidden`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/user, respond with HTTP 403

`api.currentuser.v1.test_helpers.user.get_current_user.` `not_found`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/user, respond with HTTP 404

`api.currentuser.v1.test_helpers.user.get_current_user.` `success`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/user, respond with HTTP 200

`api.currentuser.v1.test_helpers.user.get_current_user.` `unauthorized`(function)

  Mock https://portal.mnemonic.no/web/api/currentuser/v1/user, respond with HTTP 401

## Module contents